@@ -1,9 +1,9 @@
 /*
  * l10n-ja.c -
- * $Id: l10n-ja.c,v 1.2 2001/06/21 06:21:32 rug Exp $
+ * $Id: l10n-ja.c,v 1.2.4.3 2007-12-05 16:50:47 opengl2772 Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000,2001 Namazu Project All rights reserved.
+ * Copyright (C) 2000,2001,2007 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -24,17 +24,24 @@
  * 
  */
 
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
+#endif
+
+#ifdef HAVE_STRING_H
+#  include <string.h>
+#else
+#  include <strings.h>
+#endif
+
+#include "i18n.h"
+#include "l10n-ja.h"
+
 /*
  *
  * Public functions
  *
  */
-#include <string.h>
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
-#include "i18n.h"
-#include "l10n-ja.h"
 
 /* 
  * FIXME: ad-hoc function. 
@@ -47,13 +54,13 @@ nmz_is_lang_ja(void)
     const char *lang;
 
     lang = nmz_get_lang_ctype();
-    if (strcmp(lang, "japanese")) {
+    if (!strcmp(lang, "japanese")) {
 	return 1; /* TRUE */
     } 
-    if (strcmp(lang, "ja")) {
+    if (!strcmp(lang, "ja")) {
 	return 1; /* TRUE */
     } 
-    if (strncmp(lang, "ja_JP", 5)) {
+    if (!strncmp(lang, "ja_JP", 5)) {
 	return 1; /* TRUE */
     } 
     return 0; /* FALSE */
